#!/bin/sh
#
# Copyright (c) 2018, 2019  Peter Pentchev
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions
# are met:
# 1. Redistributions of source code must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
# 2. Redistributions in binary form must reproduce the above copyright
#    notice, this list of conditions and the following disclaimer in the
#    documentation and/or other materials provided with the distribution.
#
# THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
# ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
# IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
# ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
# FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
# DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
# OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
# HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
# OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
# SUCH DAMAGE.

[ -z "$CONFGET" ] && CONFGET='./confget'
[ -z "$TESTDIR" ] && TESTDIR='t'

T1="$TESTDIR/t1.ini"
T2="$TESTDIR/t2.ini"

echo '1..13'

if [ ! -f "$T1" ]; then
	echo "Bail out!  No test file $T1"
	exit 255
fi
if [ ! -f "$T2" ]; then
	echo "Bail out!  No test file $T2"
	exit 255
fi

idx=1
for args in \
    '-l -L k' \
    '-l -q sections' \
    '-l -q features' \
    '-l -q feature BASE' \
    '-l key1' \
    '-L -q sections k' \
    '-L -q features k' \
    '-L -q feature BASE k' \
    '-q sections -q features' \
    '-q sections -q feature BASE' \
    '-q sections key1' \
    '-q features -q feature BASE' \
    '-q features key1'; do
	if [ "${args#-q sections -q}" != "$args" ] || [ "${args#-q features -q}" != "$args" ]; then
		if [ "${CONFGET#*python}" != "$CONFGET" ] || [ "${CONFGET#*pypy}" != "$CONFGET" ]; then
			echo "ok $idx $args - skipped, Python argparse"
			idx="$((idx + 1))"
			continue
		fi
	fi
	v=`$CONFGET -f "$T2" $args 2>&1`
	if expr "x$v" : 'x.*Only a single ' > /dev/null || expr "x$v" : 'x.*given more than once' > /dev/null; then echo "ok $idx $args"; else echo "not ok $idx args $args v is $v"; fi
	idx="$((idx + 1))"
done
